/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#ifndef BAR_H
#define BAR_H

#include <QFont>
#include <QLinearGradient>
#include <QPen>
#include <QPoint>
#include <QRect>

class QPainter;

/**
 * This class manages one bar of the diagram.
 */
class Bar
{
public:

    /**
     * Same as the previous constructor but information is wrapped in QRect.
     * @param is QRect type.
     */
    Bar(QRect &aRect);

    //! Destructor
    ~Bar() ;

    /**
     * Sets bar rect
     * @param is QRect type.
     */
    void setRect(const QRect& aRect);

    /**
     * Return current control rect
     * @return rect.
     */
    QRect& getRect();

    /**
     * Updates a new value for the bar and calculates right value for the bar.
     * @param1 value.
     */
    void setSNRValue(int aValue );

    /**
     * Return current snr value
     * @return value.
     */
    int getSNRValue( );

    /**
     * Called by paintevent. Draws bar and defines color and height for the
     * bar by value.
     * @param is QPainter type. Needed for the drawing.
     */
    void draw(QPainter * aPainter) ;

    /**
     * Sets new ID name for the bar.
     * @param is QString type.
     */
    void setId(QString &aId) ;

    /**
     * return bar's ID as QString.
     */
    QString getId() ;


private:

    /**
     * Measures bar by the given parameters. Always called when paintevent
     * is called.
     */
    void measure();

    //! ID string of the satellite
    QString id;

    //! QPen for drawing the bar's outline
    QPen outline;

    //! Qpen for drawing the letters
    QPen letters;

    //! QFont for the letters
    QFont font;

    //! Rectangle object for the bar
    QRect barRect;

    //! Font height. used to layout drawing
    int fontHeight;

    //! Two letters (numbers) text width
    int textWidth;

    //! Coordinates for satellites ID number
    QPoint idTextPoints;

    //! Coordinates for the value text
    QPoint valueTextPoints;

    //! Modified value for drawing the bar
    int value;

    //! Height of the bar
    int barHeight;

    //! Width of the bar
    int barWidth;

};

#endif
