#ifndef GPSNEO_H_
#define GPSNEO_H_

#include <QTcpSocket>
#include <QWhereabouts>

#include "definitions.h"

class GpsData;
class Point;

class GpsNeo : public QObject
{
    Q_OBJECT

public:
    //! Constructor
    GpsNeo();

    //! Destructor.
    ~GpsNeo();

    //! stops gps when called.
    void stopGps();

    //! Starts gps when called
    void startGps();

    //! restarts gps when called. Can also be used for starting the gps
    void restartGps();

    //! Returns the used gpsData object
    /*!
     * \return A reference to used gpsData object
     */
    GpsData &getGpsData();

    //! Returns the used gpsPoint object
    /*!
     * \return A reference to used gpsPoint object
     */
    Point &getGpsPoint();
    
public slots:
    /*!
     * \Brief Reads data from the gps 
     *
     * Reads data from the gps. Moves gps data to gps structure.
     *
     */
	void updated(const QWhereaboutsUpdate &update);

private:
	//!Object to access gps with whereabouts
	QWhereabouts *whereabouts;
	
    //! Object that holds gps data
    GpsData *gpsData;

    //! Holds a single time variable and a point on the map
    Point *gpsPoint;
};


#endif /*GPSNEO_H_*/
