/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <QDebug>

#include "gps.h"    /* for reading GPS data from daemon */
#include "gpsstarter.h"
#include "maemogps.h"

const int maxErrorBufferLength = 255;

//! Constructor
GpsStarter::GpsStarter() :
        gpsBtDebugLevel(0),
        gpsDaemonDebugLevel(0),
        gpsConnectionTryingTimeOut(2),
        gpsConnectionMaxTryOuts(10)
{
}

//! Destructor
GpsStarter::~GpsStarter()
{

}

//! Starts the gps manager.
void GpsStarter::run()
{
    char errbuf[maxErrorBufferLength+1] = {0};
    gpsBtState = -1;

    bool attemptToConnect = true;
    int tryCount = 0;

    while ((gpsBtState != 0) && attemptToConnect) {
        tryCount++;
        // Clearing context
        memset(&btGpsContext, 0, sizeof(btGpsContext));

        gpsBtState = gpsbt_start( NULL,
                                 gpsBtDebugLevel,
                                 gpsDaemonDebugLevel,
                                 0, /* port, 0 equals to default 2947 */
                                 errbuf, maxErrorBufferLength,
                                 0, /* timeout, 0 equals to using default 5 seconds */
                                 &btGpsContext);

        sleep(gpsConnectionTryingTimeOut);

        if (gpsmgr_is_gpsd_running(&btGpsContext.mgr,
                                   NULL, GPSMGR_MODE_JUST_CHECK) ==
                                   GPSMGR_NOT_RUNNING) {

            if (tryCount == gpsConnectionMaxTryOuts) {
                attemptToConnect = false;
            }
        }
        else if (gpsmgr_is_gpsd_running(&btGpsContext.mgr, NULL,
                                        GPSMGR_MODE_JUST_CHECK) ==
                                        GPSMGR_RUNNING) {

            attemptToConnect = false;
        }
    }

    if (gpsBtState < 0) {
        emit gpsrunning(false, strerror(errno));
    }
    else {
        emit gpsrunning(true, NULL);
    }
}

//! Return used gps context
gpsbt_t& GpsStarter::GpsContext()
{
	return btGpsContext;

}


