/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#include <stdio.h>
#include <QString>
#include "maemogps.h"

#include "gpsbt.h"  /* GPS BT package */
#include "gpsstarter.h"

//! Constructor
MaemoGps::MaemoGps()
{
	GpsdClient::GpsdClient();
    socket = NULL;

    startingThread = NULL;
    startingThread = new GpsStarter();
    connect(startingThread, SIGNAL(gpsrunning(bool, QString)),
            this, SLOT(gpsRunning(bool, QString)));
    startingThread->start();

}

//! Destructor
MaemoGps::~MaemoGps()
{
    delete startingThread;
}

//! When starting or trying to start gps this function is called.
//! A callback function for gps starter, that is supposed to start gpsd if needed
//! gpsd is needed to be running in order to be enabled to connect that here :)
void MaemoGps::gpsRunning(bool run, QString error)
{
    GpsdClient::gpsRunning( run, error );

}

//! restarts gps when called. Can also be used for starting the gps
void MaemoGps::restartGps()
{
    stopGps();
    // if thread is not running, restart is allowed.
    if (!startingThread->isRunning()) {
        startingThread->start();
    }

}

//! stops gps when called.
void MaemoGps::stopGps()
{
	GpsdClient::stopGps();
	if(startingThread)
	{
		gpsbt_t& gpsContext = startingThread->GpsContext();
		if (gpsmgr_is_gpsd_running(&gpsContext.mgr, NULL,
								   GPSMGR_MODE_JUST_CHECK) == GPSMGR_RUNNING) {

			startingThread->quit();

			gpsbt_stop(&gpsContext);
		}
	}

}

