/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com
        Pasi Alatalo - pasi.alatalo@ixonos.com 
        Jarkko Markkanen - jarkko.markkanen@ixonos.com
        Janne Sakko - janne.sakko@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

//For NEO-DEVICE

#include <QDocumentSelector>
#include <QContentFilter>
#include <QDebug>

#include "opendialog.h"
#include "definitions.h"

//! Constructor
OpenDialog::OpenDialog(QWidget *parent)
    : QDialog(parent)
{
    setupUi(this);
 
    QDocumentSelector *selector = new QDocumentSelector;
    selector->setFilter(QContentFilter::mimeType(docMimeType));

    connect(selector, SIGNAL(documentSelected(QContent)),
        this, SLOT(openDocument(QContent)));

    gridLayout->addWidget(selector);
}

//! Opens the selected document.
void OpenDialog::openDocument(QContent document)
{
    name = document.name();
    QByteArray bytes;
    if (!document.load(bytes)) {
        qDebug() << "can't read document";      
        return;
    }
    else {
        data = QString::fromAscii(bytes);
        setResult(QDialog::Accepted);
        hide();
    }
}

//! Returns the content of the document.
QString OpenDialog::getData()
{
    return data;
}

//! Returns the name of the document.
QString OpenDialog::getName()
{
    return name;
}

