/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com
        Pasi Alatalo - pasi.alatalo@ixonos.com 
        Jarkko Markkanen - jarkko.markkanen@ixonos.com
        Janne Sakko - janne.sakko@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

//For NEO-DEVICE

#include "screenrotation.h"

#include <cstdio>
#include <fcntl.h>
#include <unistd.h>
#include <QTimer>
#include <QtopiaServiceRequest>
#include <QDebug>

//! Constructor
ScreenRotation::ScreenRotation()
    : QObject(),
    ANGLE_MIN(20),
    ANGLE_MAX(70),
    accelDevFile("/dev/input/event3")
{
    state=ROTATION_NORMAL;
    xorientation=POSITIVE;
    yorientation=POSITIVE; 

    old_rotation=0;
}

//! Destructor
ScreenRotation::~ScreenRotation()
{
}

//! Start listening to events from accelerometer.
void ScreenRotation::start(int time)
{
    fd = open(accelDevFile, O_RDONLY);
    if (fd == -1) {
        qDebug("Error opening %s", accelDevFile);
    return;
    }

    QTimer *timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(notified()));
    timer->start(time);
}

//! Rotate screen to normal position.
void ScreenRotation::stop()
{
    rotateScreen(ROTATION_NORMAL);
}

//! Determines the new rotation based on events read from data stream.
void ScreenRotation::notified()
{
    unsigned short buf[8*7];
    unsigned short angle;
    
    if (!read(fd, buf, sizeof(buf))) {
    qDebug() << "read failed";
    return;
    }

    int line;

    for (line=0; line <= 4; line++) {
        if (buf[line*8+4] == 2 && buf[line*8+5] == 0) {
       
            angle = buf[line*8+6];
            if (angle >= 0xf000) {
                angle = 0xffff - angle;
                xorientation = NEGATIVE; 
            }
            else {
                xorientation = POSITIVE;
            }
            angle /= 11;

            line++;

            if (buf[line*8+6] <= 0xf000) {
                yorientation=NEGATIVE;
            } 
            else {
                yorientation=POSITIVE;
            }

            switch (state) {
            case ROTATION_NORMAL:
                if (angle > ANGLE_MAX && xorientation==POSITIVE) {
                    state=ROTATION_90;
                }
                else if(angle > ANGLE_MAX && xorientation==NEGATIVE) {
                    state=ROTATION_270;
                }
            break;
            case ROTATION_90:
                if(angle < ANGLE_MIN && yorientation==POSITIVE) {
                    state=ROTATION_NORMAL;
                }
                else if(angle > ANGLE_MAX && xorientation==NEGATIVE 
                        && yorientation==POSITIVE) {
                    state=ROTATION_270;
                }
            break;
            case ROTATION_270:    
                if(angle < ANGLE_MIN && yorientation==POSITIVE ) {
                    state=ROTATION_NORMAL;
                }
                else if(angle > ANGLE_MAX && xorientation==POSITIVE
                        && yorientation==POSITIVE) {
                state = ROTATION_90;
                }
            break;
            default:
            break;
            }
            rotateScreen(state);
            return;
        }
    }
}

//! Rotates the screen to given angle.
void ScreenRotation::rotateScreen(int new_rotation)
{
    QtopiaServiceRequest svreq("RotationManager", "setCurrentRotation(int)");

    if(new_rotation != old_rotation) {    
    svreq << new_rotation; 
    svreq.send();
    old_rotation = new_rotation;
    }
}


