/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com
        Pasi Alatalo - pasi.alatalo@ixonos.com 
        Jarkko Markkanen - jarkko.markkanen@ixonos.com
        Janne Sakko - janne.sakko@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

//For NEO-DEVICE

#ifndef SCREENROTATION_H
#define SCREENROTATION_H
#include <QObject>

//! Class for handling UI when rotating screen.

class ScreenRotation : public QObject
{
    Q_OBJECT
public:
    //! Constructor
    ScreenRotation();

    //! Destructor
    ~ScreenRotation();

    //! Start listening to events from accelerometer.
    /*!
     * \param time Timeout interval.
     */
    void start(int time);

    //! Rotate screen to normal position.
    void stop();

private:
    //! Enumeration to indicate the rotation of device.
    enum ROTATION_STATE {
        ROTATION_NORMAL=0,
        ROTATION_270=270,
        ROTATION_90=90,
    };      
    
    //! Enumeration to indicate orientation.
    enum ORIENTATION {
        POSITIVE, 
        NEGATIVE
    };

    //! State of rotation.
    enum ROTATION_STATE state;
    
    //! State of orientation for x-axis.
    enum ORIENTATION xorientation;

    //! State of orientation for y-axis.
    enum ORIENTATION yorientation;

    //! Boundaries for screen rotation.
    const int ANGLE_MIN;
    const int ANGLE_MAX;
	
	//! File where accelerometer data is read from.
    const char* accelDevFile;
	
    //! File descripter.
    int fd;

    //! For storing rotation data.
    int old_rotation; 

    //! Rotates the screen to given angle.
    /*!
     * \param new_rotation The new angle for screen to be rotated to.
     */
    void rotateScreen(int new_rotation);



private slots:
    //! Determines the new rotation based on events read from data stream.
    void notified();

};

#endif
