/*
    Qt Mapper - A GPS map application
    Copyright (C) 2008  Ixonos Plc. Authors:

        Antero Lehtonen - antero.lehtonen@ixonos.com
        Atte Tihinen - atte.tihinen@ixonos.com
        Jaakko Putaala - jaakko.putaala@ixonos.com
        Teppo Pennanen - teppo.pennanen@ixonos.com

    Qt Mapper is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Qt Mapper is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Qt Mapper; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#ifndef __TRACKINGDATAWRITER_H__
#define __TRACKINGDATAWRITER_H__

#include <QString>
#include <QObject>
#include <QVector>

class QTextStream;

#include "trackpoint.h"

/*!
 * Class for saving track data to (gpx) XML file.
 */
class TrackingDataWriter: public QObject
{
    Q_OBJECT
public:
    /*!
     * Constructor.
     * Creates a (gpx) XML file.
     *
     * \param trackPoints The vector of track points.
     */
    TrackingDataWriter(QVector<TrackPoint> trackPoints);

    //! Destructor
    ~TrackingDataWriter();

    /*!
     * Saves XML file.
     */
    void save();

private:
    //XML string
    QString xmlDocument;

    //Text stream for saving document
    QTextStream *out;
};
#endif
